@@ -5,9 +5,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-11-26'; # DATE
+our $DATE = '2022-12-10'; # DATE
 our $DIST = 'App-MineralUtils'; # DIST
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 our %SPEC;
 
@@ -151,7 +151,7 @@ our @potassium_forms = (
     },
     {
         name => 'mg-k-citrate',
-        potassium_ratio => 39.0983/306.395, # 12.76%
+        potassium_ratio => 3*39.0983/306.395, # 12.76%
         summary => 'Potassium citrate (K3C6H5O7), in milligrams',
     },
 );
@@ -457,7 +457,7 @@ App::MineralUtils - Utilities related to mineral supplements
 
 =head1 VERSION
 
-This document describes version 0.010 of App::MineralUtils (from Perl distribution App-MineralUtils), released on 2022-11-26.
+This document describes version 0.011 of App::MineralUtils (from Perl distribution App-MineralUtils), released on 2022-12-10.
 
 =head1 DESCRIPTION
 
@@ -570,10 +570,10 @@ Result:
      },
    ],
    {
-     "table.field_aligns"  => ["number", "left", "left"],
      "table.fields"        => ["amount", "unit", "summary"],
+     "table.field_aligns"  => ["number", "left", "left"],
      "table.field_formats" => [
-                                ["number", { thousands_sep => "", precision => 3 }],
+                                ["number", { precision => 3, thousands_sep => "" }],
                                 undef,
                                 undef,
                               ],
@@ -785,19 +785,19 @@ Result:
        summary => "Potassium chloride (KCl), in milligrams",
      },
      {
-       amount  => 7.8125,
+       amount  => 2.61096605744125,
        unit    => "mg-k-citrate",
        summary => "Potassium citrate (K3C6H5O7), in milligrams",
      },
    ],
    {
      "table.fields"        => ["amount", "unit", "summary"],
+     "table.field_aligns"  => ["number", "left", "left"],
      "table.field_formats" => [
                                 ["number", { precision => 3, thousands_sep => "" }],
                                 undef,
                                 undef,
                               ],
-     "table.field_aligns"  => ["number", "left", "left"],
    },
  ]
 
@@ -907,12 +907,12 @@ Result:
      },
    ],
    {
-     "table.fields"        => ["amount", "unit", "summary"],
      "table.field_formats" => [
                                 ["number", { thousands_sep => "", precision => 3 }],
                                 undef,
                                 undef,
                               ],
+     "table.fields"        => ["amount", "unit", "summary"],
      "table.field_aligns"  => ["number", "left", "left"],
    },
  ]
